import { Group } from '../../common';

export const DECIMAL_POINT = '.' as const;

export const GROUPING_SYMBOL = ',' as const;

export const NEGATIVE = 'negative' as const;

export const NEGATIVE_SYMBOL = '-' as const;

// replace with hyphen with option
export const TENS_ONES_SEPARATOR = ' ' as const;

export const POSITIVE_SYMBOL = '+' as const;

export const SHORT_MILLIA_DELIMITER = '^' as const;

export const EXPONENT_DELIMITER = 'e' as const;

export const EMPTY_GROUP_DIGITS = '000' as const;

export const EMPTY_PLACE: Group = [EMPTY_GROUP_DIGITS, BigInt(0)];

/**
 * Ones number names.
 */
export const ONES = [
	'zero',
	'one',
	'two',
	'three',
	'four',
	'five',
	'six',
	'seven',
	'eight',
	'nine',
] as const;

export type OnesName = typeof ONES[number];

/**
 * Ten plus ones number names.
 */
export const TEN_PLUS_ONES = [
	'ten',
	'eleven',
	'twelve',
	'thirteen',
	'fourteen',
	'fifteen',
	'sixteen',
	'seventeen',
	'eighteen',
	'nineteen',
] as const;

export type TenPlusOnesName = typeof TEN_PLUS_ONES[number];

/**
 * Tens number names.
 */
export const TENS = [
	'zero',
	TEN_PLUS_ONES[0],
	'twenty',
	'thirty',
	'forty',
	'fifty',
	'sixty',
	'seventy',
	'eighty',
	'ninety',
] as const;

export type TensName = typeof TENS[number];

/**
 * Hundreds name.
 */
export const HUNDRED = 'hundred' as const;

/**
 * Thousands name.
 */
export const THOUSAND = 'thousand' as const;

// export const ILLION_ORDINAL_SUFFIX = 'illionth' as const;

// export const THOUSAND_ORDINAL = 'thousandth' as const;

/**
 * Special millions name.
 */
export const MILLIONS_SPECIAL_PREFIXES = [
	'',
	'm',
	'b',
	'tr',
	'quadr',
	'quint',
	'sext',
	'sept',
	'oct',
	'non',
] as const;

export type MillionsSpecialPrefix = Exclude<typeof MILLIONS_SPECIAL_PREFIXES[number], ''>;

/**
 * Millions name.
 */
export const MILLIONS_PREFIXES = [
	'',
	'un',
	'duo',
	'tre',
	'quattuor',
	'quin',
	'sex',
	'septen',
	'octo',
	'novem',
] as const;

export type MillionsPrefix = Exclude<typeof MILLIONS_PREFIXES[number], ''>;

/**
 * Decillions name.
 */
export const DECILLIONS_PREFIXES = [
	'',
	'dec',
	'vigin',
	'trigin',
	'quadragin',
	'quinquagin',
	'sexagin',
	'septuagin',
	'octogin',
	'nonagin',
] as const;

export type DecillionsPrefix = Exclude<typeof DECILLIONS_PREFIXES[number], ''>;

/**
 * Centillions name.
 */
export const CENTILLIONS_PREFIXES = [
	'',
	'cen',
	'duocen',
	'trecen',
	'quadringen',
	'quingen',
	'sescen',
	'septingen',
	'octingen',
	'nongen',
] as const;

export type CentillionsPrefix = Exclude<typeof CENTILLIONS_PREFIXES[number], ''>;

/**
 * Prefix for millia- number names.
 */
export const MILLIA_PREFIX = 'millia' as const;

/**
 * Suffix for -illion number names.
 */
export const ILLION_SUFFIX = 'illion' as const;
